summaryrefslogtreecommitdiff
path: root/include/svx/fmgridif.hxx
diff options
context:
space:
mode:
authorNoel Grandin <noelgrandin@gmail.com>2016-01-19 19:45:45 +0200
committerNoel Grandin <noel@peralex.com>2016-01-25 08:52:03 +0200
commit752cd07d085ac0aadc99bd512d49072843139032 (patch)
tree21ff2f55761b34bfdd721b5e1ed43333e8874e46 /include/svx/fmgridif.hxx
parent0e7cd653ea90da388820220bf6a3eb140b57bbd6 (diff)
InterfaceContainer2 with vector instead of Sequence
create an InterfaceContainer2 class to replace InterfaceContainer. It uses a std::vector instead of a Sequence for the mutable listener list, which provides far better performance. Switch all our internal use-sites to the new class. Change-Id: I6b56cfa511ded2395faa22e68fab3b2f16c3cb88
Diffstat (limited to 'include/svx/fmgridif.hxx')
-rw-r--r--include/svx/fmgridif.hxx22
1 files changed, 11 insertions, 11 deletions
diff --git a/include/svx/fmgridif.hxx b/include/svx/fmgridif.hxx
index 25370fafe376..9fe961b3452a 100644
--- a/include/svx/fmgridif.hxx
+++ b/include/svx/fmgridif.hxx
@@ -67,7 +67,7 @@ public:
// FmXModifyMultiplexer
class SAL_WARN_UNUSED FmXModifyMultiplexer :public OWeakSubObject
- ,public ::cppu::OInterfaceContainerHelper
+ ,public ::comphelper::OInterfaceContainerHelper2
,public css::util::XModifyListener
{
public:
@@ -81,7 +81,7 @@ public:
// css::util::XModifyListener
virtual void SAL_CALL modified(const css::lang::EventObject& Source) throw(css::uno::RuntimeException, std::exception) override;
// resolve ambiguity : both OWeakObject and OInterfaceContainerHelper have these memory operators
void * SAL_CALL operator new( size_t size ) throw() { return OWeakSubObject::operator new(size); }
void SAL_CALL operator delete( void * p ) throw() { OWeakSubObject::operator delete(p); }
};
@@ -90,7 +90,7 @@ public:
// FmXUpdateMultiplexer
class SAL_WARN_UNUSED FmXUpdateMultiplexer : public OWeakSubObject,
- public ::cppu::OInterfaceContainerHelper,
+ public ::comphelper::OInterfaceContainerHelper2,
public css::form::XUpdateListener
{
public:
@@ -106,7 +106,7 @@ public:
virtual sal_Bool SAL_CALL approveUpdate(const css::lang::EventObject &) throw(css::uno::RuntimeException, std::exception) override;
virtual void SAL_CALL updated(const css::lang::EventObject &) throw(css::uno::RuntimeException, std::exception) override;
// resolve ambiguity : both OWeakObject and OInterfaceContainerHelper have these memory operators
void * SAL_CALL operator new( size_t size ) throw() { return OWeakSubObject::operator new(size); }
void SAL_CALL operator delete( void * p ) throw() { OWeakSubObject::operator delete(p); }
};
@@ -115,7 +115,7 @@ public:
// FmXSelectionMultiplexer
class SAL_WARN_UNUSED FmXSelectionMultiplexer :public OWeakSubObject
- ,public ::cppu::OInterfaceContainerHelper
+ ,public ::comphelper::OInterfaceContainerHelper2
,public css::view::XSelectionChangeListener
{
public:
@@ -130,7 +130,7 @@ public:
// css::view::XSelectionChangeListener
virtual void SAL_CALL selectionChanged( const css::lang::EventObject& aEvent ) throw (css::uno::RuntimeException, std::exception) override;
// resolve ambiguity : both OWeakObject and OInterfaceContainerHelper have these memory operators
void * SAL_CALL operator new( size_t size ) throw() { return OWeakSubObject::operator new(size); }
void SAL_CALL operator delete( void * p ) throw() { OWeakSubObject::operator delete(p); }
};
@@ -139,7 +139,7 @@ public:
// FmXGridControlMultiplexer
class SAL_WARN_UNUSED FmXGridControlMultiplexer :public OWeakSubObject
- ,public ::cppu::OInterfaceContainerHelper
+ ,public ::comphelper::OInterfaceContainerHelper2
,public css::form::XGridControlListener
{
public:
@@ -154,7 +154,7 @@ public:
// css::view::XSelectionChangeListener
virtual void SAL_CALL columnChanged( const css::lang::EventObject& _event ) throw (css::uno::RuntimeException, std::exception) override;
// resolve ambiguity : both OWeakObject and OInterfaceContainerHelper have these memory operators
void * SAL_CALL operator new( size_t size ) throw() { return OWeakSubObject::operator new(size); }
void SAL_CALL operator delete( void * p ) throw() { OWeakSubObject::operator delete(p); }
};
@@ -163,7 +163,7 @@ public:
// FmXContainerMultiplexer
class SAL_WARN_UNUSED FmXContainerMultiplexer : public OWeakSubObject,
- public ::cppu::OInterfaceContainerHelper,
+ public ::comphelper::OInterfaceContainerHelper2,
public css::container::XContainerListener
{
public:
@@ -179,7 +179,7 @@ public:
virtual void SAL_CALL elementRemoved(const css::container::ContainerEvent& Event) throw(css::uno::RuntimeException, std::exception) override;
virtual void SAL_CALL elementReplaced(const css::container::ContainerEvent& Event) throw(css::uno::RuntimeException, std::exception) override;
// resolve ambiguity : both OWeakObject and OInterfaceContainerHelper have these memory operators
void * SAL_CALL operator new( size_t size ) throw() { return OWeakSubObject::operator new(size); }
void SAL_CALL operator delete( void * p ) throw() { OWeakSubObject::operator delete(p); }
};
@@ -336,7 +336,7 @@ class SAL_WARN_UNUSED SVX_DLLPUBLIC FmXGridPeer:
{
css::uno::Reference< css::container::XIndexContainer > m_xColumns;
css::uno::Reference< css::sdbc::XRowSet > m_xCursor;
- ::cppu::OInterfaceContainerHelper m_aModifyListeners,
+ ::comphelper::OInterfaceContainerHelper2 m_aModifyListeners,
m_aUpdateListeners,
m_aContainerListeners,
m_aSelectionListeners,
@@ -81,7 +81,7 @@ public:
// css::util::XModifyListener
virtual void SAL_CALL modified(const css::lang::EventObject& Source) throw(css::uno::RuntimeException, std::exception) override;
-// resolve ambiguity : both OWeakObject and OInterfaceContainerHelper have these memory operators
+// resolve ambiguity : both OWeakObject and OInterfaceContainerHelper2 have these memory operators
void * SAL_CALL operator new( size_t size ) throw() { return OWeakSubObject::operator new(size); }
void SAL_CALL operator delete( void * p ) throw() { OWeakSubObject::operator delete(p); }
@@ -106,7 +106,7 @@ public:
virtual sal_Bool SAL_CALL approveUpdate(const css::lang::EventObject &) throw(css::uno::RuntimeException, std::exception) override;
virtual void SAL_CALL updated(const css::lang::EventObject &) throw(css::uno::RuntimeException, std::exception) override;
-// resolve ambiguity : both OWeakObject and OInterfaceContainerHelper have these memory operators
+// resolve ambiguity : both OWeakObject and OInterfaceContainerHelper2 have these memory operators
void * SAL_CALL operator new( size_t size ) throw() { return OWeakSubObject::operator new(size); }
void SAL_CALL operator delete( void * p ) throw() { OWeakSubObject::operator delete(p); }
@@ -130,7 +130,7 @@ public:
// css::view::XSelectionChangeListener
virtual void SAL_CALL selectionChanged( const css::lang::EventObject& aEvent ) throw (css::uno::RuntimeException, std::exception) override;
-// resolve ambiguity : both OWeakObject and OInterfaceContainerHelper have these memory operators
+// resolve ambiguity : both OWeakObject and OInterfaceContainerHelper2 have these memory operators
void * SAL_CALL operator new( size_t size ) throw() { return OWeakSubObject::operator new(size); }
void SAL_CALL operator delete( void * p ) throw() { OWeakSubObject::operator delete(p); }
@@ -154,7 +154,7 @@ public:
// css::view::XSelectionChangeListener
virtual void SAL_CALL columnChanged( const css::lang::EventObject& _event ) throw (css::uno::RuntimeException, std::exception) override;
-// resolve ambiguity : both OWeakObject and OInterfaceContainerHelper have these memory operators
+// resolve ambiguity : both OWeakObject and OInterfaceContainerHelper2 have these memory operators
void * SAL_CALL operator new( size_t size ) throw() { return OWeakSubObject::operator new(size); }
void SAL_CALL operator delete( void * p ) throw() { OWeakSubObject::operator delete(p); }
@@ -179,7 +179,7 @@ public:
virtual void SAL_CALL elementRemoved(const css::container::ContainerEvent& Event) throw(css::uno::RuntimeException, std::exception) override;
virtual void SAL_CALL elementReplaced(const css::container::ContainerEvent& Event) throw(css::uno::RuntimeException, std::exception) override;
-// resolve ambiguity : both OWeakObject and OInterfaceContainerHelper have these memory operators
+// resolve ambiguity : both OWeakObject and OInterfaceContainerHelper2 have these memory operators
void * SAL_CALL operator new( size_t size ) throw() { return OWeakSubObject::operator new(size); }
void SAL_CALL operator delete( void * p ) throw() { OWeakSubObject::operator delete(p); }